@@ -48,6 +48,12 @@ module Nanoc::DataSources
   #
   # @api private
   class Filesystem < Nanoc::DataSource
+    class AmbiguousMetadataAssociationError < ::Nanoc::Core::Error
+      def initialize(content_filenames, meta_filename)
+        super("There are multiple content files (#{content_filenames.sort.join(', ')}) that could match the file containing metadata (#{meta_filename}).")
+      end
+    end
+
     identifiers :filesystem, :filesystem_unified
 
     # See {Nanoc::DataSource#up}.
@@ -85,9 +91,9 @@ module Nanoc::DataSources
     def changes_for_dir(dir)
       require 'listen'
 
-      Nanoc::ChangesStream.new do |cl|
+      Nanoc::Core::ChangesStream.new do |cl|
         listener =
-          Listen.to(dir, latency: 0.0, wait_for_delay: 0.0) do |_modifieds, _addeds, _deleteds|
+          Listen.to(dir, latency: 0.1, wait_for_delay: 0.0) do |_modifieds, _addeds, _deleteds|
             cl.unknown
           end
 
@@ -203,7 +209,7 @@ module Nanoc::DataSources
 
         have_possible_ambiguity = meta_filename && content_filenames.size > 1
         if have_possible_ambiguity && content_filenames.count { |fn| !parser.frontmatter?(fn) } != 1
-          raise Nanoc::Int::Errors::AmbiguousMetadataAssociation.new(content_filenames, meta_filename)
+          raise Nanoc::DataSources::Filesystem::AmbiguousMetadataAssociationError.new(content_filenames, meta_filename)
         end
 
         content_filenames.each do |content_filename|
@@ -356,9 +362,9 @@ module Nanoc::DataSources
 
       regex =
         if /(^|\/)index(\.[^\/]+)?$/.match?(filename)
-          allow_periods_in_identifiers? ? /\/?(index)?(\.[^\/\.]+)?$/ : /\/?index(\.[^\/]+)?$/
+          allow_periods_in_identifiers? ? /\/?(index)?(\.[^\/.]+)?$/ : /\/?index(\.[^\/]+)?$/
         else
-          allow_periods_in_identifiers? ? /\.[^\/\.]+$/ : /\.[^\/]+$/
+          allow_periods_in_identifiers? ? /\.[^\/.]+$/ : /\.[^\/]+$/
         end
       Nanoc::Core::Identifier.new(filename.sub(regex, ''), type: :legacy)
     end
@@ -384,7 +390,7 @@ module Nanoc::DataSources
     # @return [Regex]
     def extension_regex
       if allow_periods_in_identifiers?
-        /(\.[^\/\.]+$)/
+        /(\.[^\/.]+$)/
       else
         /(\.[^\/]+$)/
       end
